package com.qmth.teachcloud.cas.util;

import com.qmth.teachcloud.cas.util.supwisdom.CasUtils;
import com.qmth.teachcloud.cas.util.supwisdom.Constants;
import com.qmth.teachcloud.cas.util.supwisdom.LoginUser;
import com.qmth.teachcloud.exchange.common.bean.params.RedirectParams;
import com.qmth.teachcloud.exchange.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.exchange.common.service.AuthInfoService;
import com.qmth.teachcloud.exchange.common.util.ServletUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;
import java.util.Objects;

/**
 * @Description: 成都理工cas工具类
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2023/6/12
 */
@Component
public class CdutCasUtil {
    private static final Logger log = LoggerFactory.getLogger(CdutCasUtil.class);
    private String teachcloudLoginUrl = null, logoutUrl = null, returnUrl = null;
    private static final String LOGIN_BEFORE_XJU_LOGIC_API = "/api/admin/print/open/login_before_xju_logic";//西交大登录之前逻辑
    private static final String ACCESS_TOKEN_URL = "http://org.xjtu.edu.cn/openplatform/oauth/getAccessToken";
    private static final String USER_INFO_URL = "http://org.xjtu.edu.cn/openplatform/oauth/open/getUserInfo";
    private static final String LOGOUT_URL = "http://org.xjtu.edu.cn/openplatform/oauth/logout";

    @Resource
    AuthInfoService authInfoService;

    /**
     * 成都理工登录逻辑
     *
     * @param schoolCode
     * @return
     * @throws IOException
     */
    public void authentication(String schoolCode) throws IOException {
        HttpServletRequest request = ServletUtil.getRequest();
        HttpServletResponse response = ServletUtil.getResponse();
        HttpSession session = request.getSession();
        String targetUrl = CasUtils.getTargetUrl(request);
        authInfoService.appHasExpired(schoolCode);
        if (CasUtils.isLogin(session)) {
            response.sendRedirect(targetUrl);
        } else {
            if (CasUtils.hasTicket(request)) {
                LoginUser loginUser = CasUtils.getLoginUser(request);
                if (loginUser.isLogin()) {
                    CasUtils.login(loginUser, session);
                    response.sendRedirect(targetUrl);
                } else {
                    String loginUrl = CasUtils.getLoginUrl(request);
                    response.sendRedirect(loginUrl);
                }
            } else {
                String loginUrl = CasUtils.getLoginUrl(request);
                response.sendRedirect(loginUrl);
            }
        }
    }

    /**
     * 成都理工注销逻辑
     *
     * @param schoolCode
     * @throws IOException
     */
    public void logout(String schoolCode) throws IOException {
        if (Objects.isNull(logoutUrl) || Objects.equals(logoutUrl, "")) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("鉴权退出地址不存在");
        }
        HttpServletRequest request = ServletUtil.getRequest();
        HttpServletResponse response = ServletUtil.getResponse();
        authInfoService.appHasExpired(schoolCode);
        if (doLogout(request)) {
            HttpSession session = request.getSession();
            CasUtils.logout(session);
            response.sendRedirect(CasUtils.getLogoutUrl(request));
        } else {
            response.sendRedirect(CasUtils.getLogoutUrl(request));
        }
    }

    /**
     * 知学登录
     *
     * @param schoolCode
     * @return
     * @throws IOException
     */
    public RedirectParams zxzkLogin(String schoolCode) throws IOException {
        HttpServletRequest request = ServletUtil.getRequest();
        HttpSession session = request.getSession();
        RedirectParams redirectParams = null;
        if (CasUtils.isLogin(session)) {
            LoginUser loginUser = (LoginUser) session.getAttribute(Constants.LOGIN_USER_KEY);
            String account = loginUser.getAccount();
            redirectParams = new RedirectParams(account, schoolCode, logoutUrl, null);
        }
        return redirectParams;
    }

    /**
     * dologout
     *
     * @param request
     * @return
     */
    public boolean doLogout(HttpServletRequest request) {
        return true;
    }
}
